@@ -1,3 +1,4 @@
+import os
 import sys
 import time
 import logging
@@ -9,6 +10,7 @@ import matplotlib.pyplot as plt
 
 from itertools import filterfalse
 from collections import Counter
+from matplotlib import font_manager
 from GetConfig import getConfig
 
 try:
@@ -228,7 +230,7 @@ class ClusterAnalysis(object):
     # calculate pairwise Fst
     def _calculate_MDS_fst(self, population_count, fst_output):
 
-        pops = sorted(population_count.index.tolist())
+        pops = population_count.index.tolist()
         fst_df = pd.DataFrame(index=pops, columns=pops)
         pop_num = 0
         for pop1 in pops:
@@ -402,6 +404,11 @@ class ClusterAnalysis(object):
         self.logger.info('[Y-LineageTracker] Start clustering analysis')
 
         # parameters for plot
+        import warnings
+        warnings.filterwarnings('ignore')
+        font_files = font_manager.findSystemFonts(fontpaths=[os.path.split(os.path.realpath(__file__))[0] + '/sans-serif'])
+        font_list = font_manager.createFontList(font_files)
+        font_manager.fontManager.ttflist.extend(font_list)
         plt.rcParams['font.family']= 'sans-serif'
         plt.rcParams['font.sans-serif'] = ['Arial'] # font
         plt.rcParams['axes.unicode_minus'] = False
@@ -413,11 +420,14 @@ class ClusterAnalysis(object):
 
         # x and y labels
         if method == 'pca':
-            plt.xlabel('PC1  %.2f%%'% (pca.explained_variance_ratio_[0]*100), fontsize=16)
-            plt.ylabel('PC2  %.2f%%'% (pca.explained_variance_ratio_[1]*100), fontsize=16)
+            plt.xlabel('PC1  %.2f%%'% (pca.explained_variance_ratio_[0]*100), fontsize=25)
+            plt.ylabel('PC2  %.2f%%'% (pca.explained_variance_ratio_[1]*100), fontsize=25)
         elif method == 'mds':
-            plt.xlabel('Dimension1', fontsize=16)
-            plt.ylabel('Dimension2', fontsize=16)
+            plt.xlabel('Dimension1', fontsize=25)
+            plt.ylabel('Dimension2', fontsize=25)
+
+        plt.xticks(size=20)
+        plt.yticks(size=20)
 
         # traverse populations to plot scatterplot
         if 'label_list' in vars():
@@ -428,28 +438,28 @@ class ClusterAnalysis(object):
                     plt.plot(coordinates[i, 0], coordinates[i, 1], shape_list[i],
                              color=color_list[i],
                              mec='black',
-                             markersize=10,
+                             markersize=15,
                              alpha=0.9)
                 else:
                     plt.plot(coordinates[i, 0], coordinates[i, 1], shape_list[i],
                              color=color_list[i],
                              mec='black',
                              label=label_list[i],
-                             markersize=10,
+                             markersize=15,
                              alpha=0.9)
                 plot_list.append(plot)
-            plt.legend(frameon=True, fontsize=12, markerscale=0.9, shadow=True, edgecolor='dimgrey', loc='best')
+            plt.legend(frameon=True, fontsize=15, markerscale=1, shadow=True, edgecolor='dimgrey', loc='best')
         else:
             for i in range(population_data.index.size):
                 plt.plot(coordinates[num_list[i][0]:num_list[i][1], 0], coordinates[num_list[i][0]:num_list[i][1], 1], shape_list[i],
                          color=color_list[i],
                          mec='black',
-                         markersize=10,
+                         markersize=15,
                          alpha=0.7)
 
         # plot population with labels
         if population_freq.index.size < 40:
-            texts = [plt.text(x=coordinates[i, 0]+0.008, y=coordinates[i, 1]-0.01, s=population_freq.index.tolist()[i]) for i in range(len(matrix))]
+            texts = [plt.text(x=coordinates[i, 0]+0.008, y=coordinates[i, 1]-0.01, s=population_freq.index.tolist()[i], size=15) for i in range(len(matrix))]
             import warnings
             warnings.filterwarnings('ignore')
             adjust_text(texts)
