@@ -4,7 +4,6 @@ import time
 import logging
 import argparse
 import itertools
-import graphviz
 import matplotlib; matplotlib.use('Agg')
 import multiprocessing
 import pandas as pd
@@ -15,6 +14,7 @@ import matplotlib.pyplot as plt
 from operator import add
 from functools import partial
 from collections import Counter
+from matplotlib import font_manager
 from GetConfig import getConfig
 
 
@@ -54,7 +54,7 @@ def net_parser():
                         type=str,
                         dest='format',
                         action='store',
-                        choices=['fasta', 'phylip', 'nexus', 'vcf', 'matrix'],
+                        choices=['fasta', 'phylip', 'nexus', 'meg', 'vcf'],
                         help='--seq-format: The format of sequence file. This option is only required for the sequence alignment file. ')
     # optional, population file
     parser.add_argument('-p', '--population',
@@ -828,6 +828,12 @@ class HaploNetwork(object):
         length_data = length_data.astype(int)
 
         # set figure size and network class
+        import warnings
+        warnings.filterwarnings('ignore')
+        font_files = font_manager.findSystemFonts(fontpaths=[os.path.split(os.path.realpath(__file__))[0] + '/sans-serif'])
+        font_list = font_manager.createFontList(font_files)
+        font_manager.fontManager.ttflist.extend(font_list)
+        plt.rcParams['font.family']= 'sans-serif'
         plt.rcParams['font.sans-serif'] = ['Arial'] # font
         plt.rcParams['legend.handlelength'] = 1
         plt.rcParams['legend.handleheight'] = 1
@@ -881,14 +887,14 @@ class HaploNetwork(object):
         max_size = max(hap_size_per)
         size_rate = base_size/max_size
         size = [hap_size_per[i]*size_rate if i < hap_num else median_size for i in DG.nodes][:node_num]
-        size = size + [0] * length_data.size
+        size = size + [0.2] * length_data.size
 
         try:
             # color and line type
             if hap_freq_per:
                 from matplotlib.patches import Patch
                 from FilesIO import set_color_num
-                nx.draw(DG, pos=pos, arrows=False, node_color='white', node_size=min(size), style=style_list)
+                nx.draw(DG, pos=pos, arrows=False, node_color='black', node_size=min(size), style=style_list)
                 # set colors
                 colors = set_color_num(len(pops))
                 legend_elements = []
