@@ -49,7 +49,7 @@ def stat_parser():
                         type=str,
                         dest='format',
                         action='store',
-                        choices=['fasta', 'phylip', 'nexus', 'vcf'],
+                        choices=['fasta', 'phylip', 'nexus', 'meg', 'vcf'],
                         help='seq-format: The format of sequence file. \
                               This option is only required for the sequence alignment file.')
     # population file, required for calculating statistics, not required for prediction
@@ -179,9 +179,9 @@ class StatisticsAnalysis(object):
         self.logger = logging.getLogger()
         self.label = label
         if label == 'Population':
-            self.label_num = -2
+            self.label_num = 1
         else:
-            self.label_num = -1
+            self.label_num = 2
         self.skip_letters = config.get('Statistics', 'SkipLetters').split(',')
         self.haplotype_array = np.array(haplotype_data)
         self.haplotype_array_with_inds = haplotype_data.reset_index().to_numpy()
@@ -299,7 +299,7 @@ class StatisticsAnalysis(object):
         return hd_df
 
     # calculate mean pairwise differences of between two populations
-    def _between_mean_pairwise_distance(self, pop1, pop2):
+    def _between_mean_pairwise_differences(self, pop1, pop2):
 
         pop1_data = self._get_population_data(pop1)
         pop2_data = self._get_population_data(pop2)
@@ -333,7 +333,7 @@ class StatisticsAnalysis(object):
         return pi, sd
 
     # calculate mean pairwise difference within a population
-    def _within_mean_pairwise_distance(self, pop):
+    def _within_mean_pairwise_differences(self, pop):
 
         pop_haplotype_data = self._get_population_data(pop)
         n = len(pop_haplotype_data)
@@ -373,16 +373,16 @@ class StatisticsAnalysis(object):
         return pi, sd
 
     # get mean pairwise difference of all populations
-    def _calculate_mean_pairwise_distance(self):
+    def _calculate_mean_pairwise_differences(self):
 
         mpd_df = pd.DataFrame(index=self.pops, columns=self.pops)
         pop_num = 0
         for pop1 in self.pops:
             for pop2 in self.pops[pop_num:]:
                 if pop1 == pop2:
-                    pi, sd = self._within_mean_pairwise_distance(pop1)
+                    pi, sd = self._within_mean_pairwise_differences(pop1)
                 else:
-                    pi, sd = self._between_mean_pairwise_distance(pop1, pop2)
+                    pi, sd = self._between_mean_pairwise_differences(pop1, pop2)
                 if pi == 'NA':
                     mpd_df.at[pop2, pop1] = 'NA'
                 else:
@@ -832,7 +832,7 @@ class StatisticsAnalysis(object):
             hd_df.to_csv(path+'.HD.%s.txt' % self.label, sep='\t')
             self.logger.info('[Y-LineageTracker] Calculate haplotype diversity finished')
         if arguments.mpd:
-            mpd_df = self._calculate_mean_pairwise_distance()
+            mpd_df = self._calculate_mean_pairwise_differences()
             mpd_df.to_csv(path+'.MPD.%s.txt' % self.label, sep='\t')
             self.logger.info('[Y-LineageTracker] Calculate mean pairwise differences on %s level finished' % self.label)
         if arguments.gd:
